@@ -11,10 +11,10 @@ from transformers import (
 
 class K2TPipeline:
     def __init__(
-        self,
-        model: PreTrainedModel,
-        tokenizer: PreTrainedTokenizer,
-        use_cuda: bool
+            self,
+            model: PreTrainedModel,
+            tokenizer: PreTrainedTokenizer,
+            use_cuda: bool
     ):
         self.model = model
         self.tokenizer = tokenizer
@@ -58,12 +58,12 @@ class K2TPipeline:
         return texts
 
     def _tokenize(
-        self,
-        inputs,
-        padding=True,
-        truncation=True,
-        add_special_tokens=True,
-        max_length=1024,
+            self,
+            inputs,
+            padding=True,
+            truncation=True,
+            add_special_tokens=True,
+            max_length=1024,
     ):
         inputs = self.tokenizer.encode(
             inputs,
@@ -94,11 +94,11 @@ SUPPORTED_TASKS = {
 
 
 def pipeline(
-    task: str,
-    model: Optional = None,
-    tokenizer: Optional[Union[str, PreTrainedTokenizer]] = None,
-    use_cuda: Optional[bool] = True,
-    ) -> K2TPipeline:
+        task: str,
+        model: Optional = None,
+        tokenizer: Optional[Union[str, PreTrainedTokenizer]] = None,
+        use_cuda: Optional[bool] = True,
+) -> K2TPipeline:
     """
 
     :param task:
@@ -158,7 +158,5 @@ def pipeline(
 
     if task == "k2t":
         return task_class(model=model, tokenizer=tokenizer, use_cuda=use_cuda)
-    if task == "k2t-tiny":
-        return task_class(model=model, tokenizer=tokenizer, use_cuda=use_cuda)
     if task == "k2t-base":
         return task_class(model=model, tokenizer=tokenizer, use_cuda=use_cuda)
